@@ -1,11 +1,16 @@
 package Mojolicious::Plugin::Obrazi;
+use Mojo::Base 'Mojolicious::Plugin', -signatures;
 use feature ':5.26';
-use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
-sub register {
-  my ($self, $app) = @_;
+my sub _obrazi {
+  return 'Helper obrazi(…) is not implemented yet…';
+}
+
+sub register ($self, $app, $config) {
+  $app->helper(obrazi => \&_obrazi);
+  return $self;
 }
 
 1;
@@ -27,10 +32,11 @@ Mojolicious::Plugin::Obrazi - Mojolicious Plugin
 =head1 DESCRIPTION
 
 L<Mojolicious::Plugin::Obrazi> is a L<Mojolicious> plugin. It consists of a
-command that generates html for an images gallery and a not yet wirtten helper
-which produces HTML from a CSV file found in a directory containing images.
-While the command is functional already the plugin is empty. This is a yet
-early release. Todo: write the helper; prepare a demo page.
+L<Mojolicious::Command::Author::generate::obrazi|command> that generates html
+for an images gallery and a not yet wirtten L</obrazi|helper> which produces
+HTML from a CSV file found in a directory, containing images. While the command
+is functional already the plugin is empty. This is a yet early release. Todo:
+write the helper.
 
 =head1 METHODS
 
@@ -43,6 +49,15 @@ L<Mojolicious::Plugin> and implements the following new ones.
 
 Register plugin in L<Mojolicious> application.
 
+=head1 HELPERS
+
+=head2 obrazi
+
+    <!-- in a template -->
+    <%= obrazi(csv_file => 'path/to/obrazi.csv') %>
+
+Renders a gallery section in the current page. Not implemented yet.
+
 =head1 NOTES
 
 This plugin requires Perl 5.26+ and Mojolicious 9.17+.
@@ -51,7 +66,7 @@ This plugin requires Perl 5.26+ and Mojolicious 9.17+.
 
 This is free software, licensed under:
 
-  The Artistic License 2.0 (GPL Compatible)
+The Artistic License 2.0 (GPL Compatible)
 
 The full text of the license can be found in the
 LICENSE file included with this module.
